
### Set the environment -------------------------

library("tidyr")
library("tidyverse")
library("dplyr")

library("stringr")
library("ggplot2")
library("reshape2")
library("Hmisc")
library("RColorBrewer")

library("lattice")
library("gplots")

### Prepare every function that you need --------------------

setwd("N://Alfonso_Gomez//1 - Experimental Procedures//200817_CCL2_quantigene_new//CellProfAnalys")

Masked_virus <- read.csv2("200818_CCL2_quantigene_MaskedCCL2.csv", header = T, sep = ",")

as.numeric.factor <- function(x){
  as.numeric(levels(x))[x]
}


New_BVP_counting <- function(exp,strng){
  output2 <- matrix(nrow = 0, ncol = 3)
  exp_size <- unique(exp$Metadata_Well, incomparables = FALSE)
  for (f in seq_along(exp_size)){
    samp <- as.character(exp_size[f])
    #Split <- str_split_fixed(samp,"_",n = strng)
    #Virus <- Split[,5]
    #Amount <- as.numeric(Split[,4])
    #sec_spl <- str_split_fixed(samp,"_",n = strng-1)
    #good_samp <- sec_spl[,4]
    sample_matrix <- exp[exp$Metadata_Well== samp,]
    sites <- unique(sample_matrix$Metadata_Site, incomparables = FALSE)
    for (sit in seq_along(sites)){
      place <- as.character(sites[sit])
      ce <- subset(sample_matrix, (sample_matrix$Metadata_Site == place))
      ncel <- max(ce$Parent_Cell, na.rm = T)
      if (ncel==-Inf){
        output2 <- output2
      } else {
        for (c in 1:ncel){
          Particles <- length(ce[ce[,"Parent_Cell"] == c,][,1])
          if (Particles == -Inf) {
            Particles <- 0
          }
          output2 <- rbind(output2,c(samp, c, Particles))
        }
      }
    }
  }
  colnames(output2) <- c("Sample","Cell", "Particles")
  output2 <- as.data.frame(output2)
  output2$Cell <- as.numeric.factor(output2$Cell)
  output2$Particles <- as.numeric.factor(output2$Particles)
  return(output2)
}

### Measure your sample --------------------------------

# You should input into the function 
# The data frame containing your data
# The number of splits "_" depeding on the sample name for teh regular expression
# The theshold that you want to set into the hexon

Vircount <- New_BVP_counting(Masked_virus, 5)

### Subset your viruses and treatments -----------------

wt <- subset(Vircount, (Vircount$Sample == "25_wt") | 
               (Vircount$Sample == "50_wt"))

Rev <- subset(Vircount, (Vircount$Sample == "25_Rev") | 
                (Vircount$Sample == "50_Rev"))

VKR <- subset(Vircount, (Vircount$Sample == "25_VKR") | 
                (Vircount$Sample == "50_VKR"))

### Plot the results -------------------------------------------

ggplot(data = Vircount,aes(x = Sample,y = Particles))+
  geom_boxplot(color = "grey") +
  geom_point(size=1.5, position = "jitter") +
  stat_summary(fun.data=mean_sdl, fun.args = list(mult=1), 
               geom="pointrange", color="red") +
  ylab("BVP per cell") +
  #ylim(0,250) +
  theme_classic() +
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1))

write.csv2(Vircount, file = "200612_CCL2_quantigene_quant.csv")

### Calculate the mean and SD of each condition ---------------

New_calc_my_means <- function(exp){
  output2 <- matrix(nrow = 0, ncol = 4)
  exp_size <- unique(exp$Sample, incomparables = FALSE)
  for (f in seq_along(exp_size)){
    samp <- as.character(exp_size[f])
    sample_matrix <- exp[exp$Sample== samp,]
    Particles <- length(sample_matrix[,1])
    Negative <- (dim(sample_matrix[(sample_matrix$Particles == 0),])[1])/Particles
    L_Pos <- (dim(sample_matrix[(sample_matrix$Particles > 0) & (sample_matrix$Particles < 10),])[1])/Particles
    H_pos <- (dim(sample_matrix[(sample_matrix$Particles > 9),])[1])/Particles
    output2 <- rbind(output2,c(samp, Negative, L_Pos, H_pos))
  }
  colnames(output2) <- c("Sample","Negative","Low_positive", "High_positive")
  output2 <- as.data.frame(output2)
  output2$Negative <- as.numeric.factor(output2$Negative)
  output2$Low_positive <- as.numeric.factor(output2$Low_positive)
  output2$High_positive <- as.numeric.factor(output2$High_positive)
  return(output2)
}

Mean_SD <- New_calc_my_means(Vircount)

write.csv2(Mean_SD, file = "200819_CCL2_quantigene_quant.csv")
